package com.flyfish.framework.service;

import com.flyfish.framework.domain.po.Department;
import com.flyfish.framework.service.impl.BaseReactiveServiceImpl;
import org.springframework.data.mongodb.core.ReactiveMongoOperations;
import org.springframework.data.mongodb.core.query.Criteria;
import org.springframework.data.mongodb.core.query.Query;
import org.springframework.stereotype.Service;
import reactor.core.publisher.Mono;

import javax.annotation.Resource;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * 部门服务
 *
 * @author wangyu
 */
@Service
public class DepartmentService extends BaseReactiveServiceImpl<Department> {

    @Resource
    private ReactiveMongoOperations reactiveMongoOperations;

    /**
     * 获取子部门列表
     *
     * @return 结果
     */
    public Mono<Set<String>> getSubCodes(Set<String> parents) {
        Query query = Query.query(Criteria.where("parentIds").in(parents));
        query.fields().include("_id");
        return reactiveMongoOperations.find(query, Department.class).map(Department::getId).collect(Collectors.toSet());
    }
}
